# Swagger\Client\StoreHarmonyOrderingApi

All URIs are relative to *https://storeharmony.com/webapi*

Method | HTTP request | Description
------------- | ------------- | -------------
[**loadDeliveryServices**](StoreHarmonyOrderingApi.md#loaddeliveryservices) | **GET** /{storeid}/delivery_services | retrieves the list of delivery services according to the zones supported by the store
[**payForOrderViaCustomGateway**](StoreHarmonyOrderingApi.md#payfororderviacustomgateway) | **POST** /{storeid}/order/pay | After an order has been placed and created with Storeharmony, the client can retrieve the order ID and use it to generate payment reference on their custom gateway implementation. They can use this call to pass the reference back to the storeharmony to use to verify the payment has been made. Popular gateways supported includes &#x27;pastack&#x27;, &#x27;flutterwave&#x27;, &#x27;global accelerex&#x27;, &#x27;sterling&#x27;
[**payForOrderViaInternalGateway**](StoreHarmonyOrderingApi.md#payfororderviainternalgateway) | **GET** /{storeid}/order/pay/{orderid} | After an order is made, you place this call to request storeharmony to give you a payment link to redirect customer to for payment. Gateway settngs are made via customer settings
[**placeOrderToStore**](StoreHarmonyOrderingApi.md#placeordertostore) | **POST** /{storeid}/order | places order of listed products to the merchant store. Note that a payment redirect link is also returned which allows the current buyer to make payment into this store if required. An implementation will redirect the customer to this link and later use /storeid/orderid to track the status of payment on this particular order
[**verifyOrderPlaced**](StoreHarmonyOrderingApi.md#verifyorderplaced) | **GET** /{storeid}/order/{orderid} | retrieve an Order from the store to check the status

# **loadDeliveryServices**
> \Swagger\Client\com.storeharmony.api\WebStore loadDeliveryServices($storeid)

retrieves the list of delivery services according to the zones supported by the store

A store owner can map out the price of making deliveries to each part of their coverage. A zone could be titled 'lagos mainland delivery' or 'central area delivery'. Prices are listed per KG

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

$apiInstance = new Swagger\Client\com.storeharmony.api\StoreHarmonyOrderingApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client()
);
$storeid = "storeid_example"; // string | The store id of the specific store

try {
    $result = $apiInstance->loadDeliveryServices($storeid);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling StoreHarmonyOrderingApi->loadDeliveryServices: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **storeid** | **string**| The store id of the specific store |

### Return type

[**\Swagger\Client\com.storeharmony.api\WebStore**](../Model/WebStore.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **payForOrderViaCustomGateway**
> \Swagger\Client\com.storeharmony.api\WebStore payForOrderViaCustomGateway($body, $storeid)

After an order has been placed and created with Storeharmony, the client can retrieve the order ID and use it to generate payment reference on their custom gateway implementation. They can use this call to pass the reference back to the storeharmony to use to verify the payment has been made. Popular gateways supported includes 'pastack', 'flutterwave', 'global accelerex', 'sterling'

Send payment for an already placed order. This call is made to notify storeharmony that an order has been paid for using a custom payment gateway implementation

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

$apiInstance = new Swagger\Client\com.storeharmony.api\StoreHarmonyOrderingApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client()
);
$body = new \Swagger\Client\com.storeharmony.api\WebOrderPayment(); // \Swagger\Client\com.storeharmony.api\WebOrderPayment | Details of payment for an order
$storeid = "storeid_example"; // string | The store id of the specific store

try {
    $result = $apiInstance->payForOrderViaCustomGateway($body, $storeid);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling StoreHarmonyOrderingApi->payForOrderViaCustomGateway: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\Swagger\Client\com.storeharmony.api\WebOrderPayment**](../Model/WebOrderPayment.md)| Details of payment for an order |
 **storeid** | **string**| The store id of the specific store |

### Return type

[**\Swagger\Client\com.storeharmony.api\WebStore**](../Model/WebStore.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **payForOrderViaInternalGateway**
> \Swagger\Client\com.storeharmony.api\WebStore payForOrderViaInternalGateway($storeid, $orderid)

After an order is made, you place this call to request storeharmony to give you a payment link to redirect customer to for payment. Gateway settngs are made via customer settings

To allow merchants use the embedded wallet function on their storeharmony or stocker, this call is important for payment processing. After an order is made, you place this call to request storeharmony to give you a payment link to redirect customer to for payment

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

$apiInstance = new Swagger\Client\com.storeharmony.api\StoreHarmonyOrderingApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client()
);
$storeid = "storeid_example"; // string | The store id of the specific store
$orderid = "orderid_example"; // string | The orderid of the Order to be traced from the store whi

try {
    $result = $apiInstance->payForOrderViaInternalGateway($storeid, $orderid);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling StoreHarmonyOrderingApi->payForOrderViaInternalGateway: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **storeid** | **string**| The store id of the specific store |
 **orderid** | **string**| The orderid of the Order to be traced from the store whi |

### Return type

[**\Swagger\Client\com.storeharmony.api\WebStore**](../Model/WebStore.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **placeOrderToStore**
> \Swagger\Client\com.storeharmony.api\WebStore placeOrderToStore($body, $storeid)

places order of listed products to the merchant store. Note that a payment redirect link is also returned which allows the current buyer to make payment into this store if required. An implementation will redirect the customer to this link and later use /storeid/orderid to track the status of payment on this particular order

Creates an order which is placed to the store dashboard for the merchant to immediately attend from their point of sales

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

$apiInstance = new Swagger\Client\com.storeharmony.api\StoreHarmonyOrderingApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client()
);
$body = new \Swagger\Client\com.storeharmony.api\WebOrder(); // \Swagger\Client\com.storeharmony.api\WebOrder | unique identifier of inventory item
$storeid = "storeid_example"; // string | The store id of the specific store

try {
    $result = $apiInstance->placeOrderToStore($body, $storeid);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling StoreHarmonyOrderingApi->placeOrderToStore: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\Swagger\Client\com.storeharmony.api\WebOrder**](../Model/WebOrder.md)| unique identifier of inventory item |
 **storeid** | **string**| The store id of the specific store |

### Return type

[**\Swagger\Client\com.storeharmony.api\WebStore**](../Model/WebStore.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **verifyOrderPlaced**
> \Swagger\Client\com.storeharmony.api\WebStore verifyOrderPlaced($storeid, $orderid)

retrieve an Order from the store to check the status

Returns the details about the provided Order ID which also indicates if there is any successful payments and payment references on it

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

$apiInstance = new Swagger\Client\com.storeharmony.api\StoreHarmonyOrderingApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client()
);
$storeid = "storeid_example"; // string | The store id of the specific store
$orderid = "orderid_example"; // string | The orderid of the Order to be traced from the store whi

try {
    $result = $apiInstance->verifyOrderPlaced($storeid, $orderid);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling StoreHarmonyOrderingApi->verifyOrderPlaced: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **storeid** | **string**| The store id of the specific store |
 **orderid** | **string**| The orderid of the Order to be traced from the store whi |

### Return type

[**\Swagger\Client\com.storeharmony.api\WebStore**](../Model/WebStore.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

